@@ -1,18 +1,27 @@
+from typing import Any, Dict
+from vorta.utils import borg_compat
 from .borg_job import BorgJob
 
 
 class BorgCheckJob(BorgJob):
-
     def started_event(self):
         self.app.backup_started_event.emit()
-        self.app.backup_progress_event.emit(self.tr('Starting consistency check...'))
+        self.app.backup_progress_event.emit(self.tr('Starting consistency check…'))
 
-    def finished_event(self, result):
+    def finished_event(self, result: Dict[str, Any]):
+        """
+        Process that the job terminated with the given results.
+
+        Parameters
+        ----------
+        result : Dict[str, Any]
+            The (json-like) dictionary containing the job results.
+        """
         self.app.backup_finished_event.emit(result)
         self.result.emit(result)
         if result['returncode'] != 0:
             self.app.backup_progress_event.emit(self.tr('Repo check failed. See logs for details.'))
-            self.app.check_failed_event.emit(self.params['repo_url'])
+            self.app.check_failed_event.emit(result)
         else:
             self.app.backup_progress_event.emit(self.tr('Check completed.'))
 
@@ -24,8 +33,11 @@ class BorgCheckJob(BorgJob):
         else:
             ret['ok'] = False  # Set back to false, so we can do our own checks here.
 
-        cmd = ['borg', 'check', '--info', '--log-json']
-        cmd.append(f'{profile.repo.url}')
+        cmd = ['borg', 'check', '--info', '--log-json', '--progress']
+        if borg_compat.check('V2'):
+            cmd = cmd + ["-r", profile.repo.url]
+        else:
+            cmd.append(f'{profile.repo.url}')
 
         ret['ok'] = True
         ret['cmd'] = cmd
