@@ -1,11 +1,10 @@
 import os
-import tempfile
 import subprocess
+import tempfile
 from datetime import datetime as dt
-
 from vorta.i18n import trans_late
-from vorta.utils import format_archive_name, borg_compat, get_network_status_monitor
-from vorta.models import SourceFileModel, ArchiveModel, WifiSettingModel, RepoModel
+from vorta.store.models import ArchiveModel, RepoModel, SourceFileModel, WifiSettingModel
+from vorta.utils import borg_compat, format_archive_name, get_network_status_monitor
 from .borg_job import BorgJob
 
 
@@ -16,18 +15,19 @@ class BorgCreateJob(BorgJob):
                 snapshot_id=result['data']['archive']['id'],
                 defaults={
                     'name': result['data']['archive']['name'],
-                    'time': dt.fromisoformat(result['data']['archive']['start']),
+                    # SQLite can't save timezone, so we remove it here. TODO: Keep as UTC?
+                    'time': dt.fromisoformat(result['data']['archive']['start']).replace(tzinfo=None),
                     'repo': result['params']['repo_id'],
                     'duration': result['data']['archive']['duration'],
-                    'size': result['data']['archive']['stats']['deduplicated_size']
-                }
+                    'size': result['data']['archive']['stats']['deduplicated_size'],
+                },
             )
             new_archive.save()
             if 'cache' in result['data'] and created:
                 stats = result['data']['cache']['stats']
                 repo = RepoModel.get(id=result['params']['repo_id'])
                 repo.total_size = stats['total_size']
-                repo.unique_csize = stats['unique_csize']
+                # repo.unique_csize = stats['unique_csize']
                 repo.unique_size = stats['unique_size']
                 repo.total_unique_chunks = stats['total_unique_chunks']
                 repo.save()
@@ -58,7 +58,7 @@ class BorgCreateJob(BorgJob):
                 'repo_url': params['repo'].url,
                 'profile_name': params['profile'].name,
                 'profile_slug': params['profile'].slug(),
-                'returncode': str(returncode)
+                'returncode': str(returncode),
             }
             proc = subprocess.run(cmd, shell=True, env=env)
             return proc.returncode
@@ -78,7 +78,18 @@ class BorgCreateJob(BorgJob):
             ret['ok'] = False  # Set back to False, so we can do our own checks here.
 
         n_backup_folders = SourceFileModel.select().count()
-        if n_backup_folders == 0:
+
+        # cmd options like `--paths-from-command` require a command
+        # that is appended to the arguments
+        # $ borg create --paths-from-command repo::archive1 -- find /home/user -type f -size -76M
+        extra_cmd_options = []
+        suffix_command = []
+        if profile.repo.create_backup_cmd:
+            s1, sep, s2 = profile.repo.create_backup_cmd.partition('-- ')
+            extra_cmd_options = s1.split()
+            suffix_command = (sep + s2).split()
+
+        if n_backup_folders == 0 and '--paths-from-command' not in extra_cmd_options:
             ret['message'] = trans_late('messages', 'Add some folders to back up first.')
             return ret
 
@@ -86,20 +97,19 @@ class BorgCreateJob(BorgJob):
         current_wifi = network_status_monitor.get_current_wifi()
         if current_wifi is not None:
             wifi_is_disallowed = WifiSettingModel.select().where(
-                (
-                    WifiSettingModel.ssid == current_wifi
-                ) & (
-                    WifiSettingModel.allowed == False  # noqa
-                ) & (
-                    WifiSettingModel.profile == profile
-                )
+                (WifiSettingModel.ssid == current_wifi)
+                & (WifiSettingModel.allowed == False)  # noqa
+                & (WifiSettingModel.profile == profile)
             )
             if wifi_is_disallowed.count() > 0 and profile.repo.is_remote_repo():
                 ret['message'] = trans_late('messages', 'Current Wifi is not allowed.')
                 return ret
 
-        if profile.repo.is_remote_repo() and profile.dont_run_on_metered_networks \
-                and network_status_monitor.is_network_metered():
+        if (
+            profile.repo.is_remote_repo()
+            and profile.dont_run_on_metered_networks
+            and network_status_monitor.is_network_metered()
+        ):
             ret['message'] = trans_late('messages', 'Not running backup over metered connection.')
             return ret
 
@@ -116,7 +126,10 @@ class BorgCreateJob(BorgJob):
             return ret
 
         if 'zstd' in profile.compression and not borg_compat.check('ZSTD'):
-            ret['message'] = trans_late('messages', 'Your current Borg version does not support ZStd compression.')
+            ret['message'] = trans_late(
+                'messages',
+                'Your current Borg version does not support ZStd compression.',
+            )
             return ret
 
         cmd = [
@@ -131,9 +144,7 @@ class BorgCreateJob(BorgJob):
             '-C',
             profile.compression,
         ]
-
-        if profile.repo.create_backup_cmd:
-            cmd.extend(profile.repo.create_backup_cmd.split(' '))
+        cmd += extra_cmd_options
 
         # Add excludes
         # Partly inspired by borgmatic/borgmatic/borg/create.py
@@ -145,10 +156,11 @@ class BorgCreateJob(BorgJob):
                     exclude_dirs.append(expanded_directory)
 
             if exclude_dirs:
-                pattern_file = tempfile.NamedTemporaryFile('w', delete=False)
+                pattern_file = tempfile.NamedTemporaryFile('w', delete=True)
                 pattern_file.write('\n'.join(exclude_dirs))
                 pattern_file.flush()
                 cmd.extend(['--exclude-from', pattern_file.name])
+                ret['cleanup_files'].append(pattern_file)
 
         if profile.exclude_if_present is not None:
             for f in profile.exclude_if_present.split('\n'):
@@ -157,12 +169,18 @@ class BorgCreateJob(BorgJob):
 
         # Add repo url and source dirs.
         new_archive_name = format_archive_name(profile, profile.new_archive_name)
-        cmd.append(f"{profile.repo.url}::{new_archive_name}")
+
+        if borg_compat.check('V2'):
+            cmd += ["-r", profile.repo.url, new_archive_name]
+        else:
+            cmd.append(f"{profile.repo.url}::{new_archive_name}")
 
         for f in SourceFileModel.select().where(SourceFileModel.profile == profile.id):
             cmd.append(f.dir)
 
-        ret['message'] = trans_late('messages', 'Starting backup...')
+        cmd += suffix_command
+
+        ret['message'] = trans_late('messages', 'Starting backup…')
         ret['ok'] = True
         ret['cmd'] = cmd
 
