@@ -1,12 +1,11 @@
-from .borg_thread import BorgThread
 from vorta.utils import borg_compat
+from .borg_job import BorgJob
 
 
-class BorgDiffThread(BorgThread):
-
+class BorgDiffJob(BorgJob):
     def started_event(self):
         self.app.backup_started_event.emit()
-        self.app.backup_progress_event.emit(self.tr('Requesting differences between archives...'))
+        self.app.backup_progress_event.emit(self.tr('Requesting differences between archives…'))
 
     def finished_event(self, result):
         self.app.backup_finished_event.emit(result)
@@ -25,10 +24,11 @@ class BorgDiffThread(BorgThread):
             ret['cmd'].append('--json-lines')
             ret['json_lines'] = True
 
-        ret['cmd'].extend([
-            f'{profile.repo.url}::{archive_name_1}',
-            f'{archive_name_2}'
-        ])
+        if borg_compat.check('V2'):
+            ret['cmd'].extend(['-r', profile.repo.url, archive_name_1, archive_name_2])
+        else:
+            ret['cmd'].extend([f'{profile.repo.url}::{archive_name_1}', archive_name_2])
+
         ret['ok'] = True
         ret['archive_name_older'] = archive_name_1
         ret['archive_name_newer'] = archive_name_2
