@@ -1,13 +1,13 @@
 from datetime import datetime as dt
+from vorta.store.models import ArchiveModel, RepoModel
+from vorta.utils import borg_compat
 from .borg_job import BorgJob
-from vorta.models import ArchiveModel, RepoModel
 
 
 class BorgListRepoJob(BorgJob):
-
     def started_event(self):
         self.app.backup_started_event.emit()
-        self.app.backup_progress_event.emit(self.tr('Refreshing archives...'))
+        self.app.backup_progress_event.emit(self.tr('Refreshing archives…'))
 
     def finished_event(self, result):
         self.app.backup_finished_event.emit(result)
@@ -22,7 +22,10 @@ class BorgListRepoJob(BorgJob):
         else:
             ret['ok'] = False  # Set back to false, so we can do our own checks here.
 
-        cmd = ['borg', 'list', '--info', '--log-json', '--json']
+        if borg_compat.check('V2'):
+            cmd = ['borg', 'rlist', '--info', '--log-json', '--json', '-r']
+        else:
+            cmd = ['borg', 'list', '--info', '--log-json', '--json']
         cmd.append(f'{profile.repo.url}')
 
         ret['ok'] = True
@@ -49,7 +52,7 @@ class BorgListRepoJob(BorgJob):
                     repo=repo.id,
                     defaults={
                         'name': archive['name'],
-                        'time': dt.fromisoformat(archive['time'])
-                    }
+                        'time': dt.fromisoformat(archive['time']).replace(tzinfo=None),
+                    },
                 )
                 new_archive.save()
