@@ -1,13 +1,10 @@
 import os
 from pathlib import PurePath
-
 from PyQt5 import QtCore, uic
 from PyQt5.QtCore import QMimeData, QUrl
 from PyQt5.QtWidgets import QApplication, QMenu, QMessageBox
-
 from vorta.store.models import ArchiveModel, BackupProfileMixin, RepoModel
 from vorta.utils import borg_compat, get_asset, get_private_keys, pretty_bytes
-
 from .repo_add_dialog import AddRepoWindow, ExistingRepoWindow
 from .ssh_dialog import SSHAddWindow
 from .utils import get_colored_icon
@@ -25,17 +22,14 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
         self.setupUi(parent)
 
         # Populate dropdowns
-        self.populate_repositories()
         self.repoRemoveToolbutton.clicked.connect(self.repo_unlink_action)
         self.copyURLbutton.clicked.connect(self.copy_URL_action)
 
         # init repo add button
         self.menuAddRepo = QMenu(self.bAddRepo)
 
-        self.menuAddRepo.addAction(self.tr("New Repository…"),
-                                   self.new_repo)
-        self.menuAddRepo.addAction(self.tr("Existing Repository…"),
-                                   self.add_existing_repo)
+        self.menuAddRepo.addAction(self.tr("New Repository…"), self.new_repo)
+        self.menuAddRepo.addAction(self.tr("Existing Repository…"), self.add_existing_repo)
 
         self.bAddRepo.setMenu(self.menuAddRepo)
 
@@ -65,9 +59,13 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
         self.sshKeyToClipboardButton.clicked.connect(self.ssh_copy_to_clipboard_action)
         self.bAddSSHKey.clicked.connect(self.create_ssh_key)
 
-        self.populate_from_profile()
         self.set_icons()
 
+        # Connect to palette change
+        QApplication.instance().paletteChanged.connect(lambda p: self.set_icons())
+
+        self.populate_from_profile()  # needs init of ssh and compression items
+
     def set_icons(self):
         self.bAddSSHKey.setIcon(get_colored_icon("plus"))
         self.bAddRepo.setIcon(get_colored_icon("plus"))
@@ -77,19 +75,20 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
 
     def set_repos(self):
         self.repoSelector.clear()
+        self.repoSelector.addItem(self.tr('No repository selected'), None)
         for repo in RepoModel.select():
             self.repoSelector.addItem(repo.url, repo.id)
 
-    def populate_repositories(self):
+    def populate_from_profile(self):
         try:
             self.repoSelector.currentIndexChanged.disconnect(self.repo_select_action)
         except TypeError:  # raised when signal is not connected
             pass
-        self.set_repos()
-        self.populate_from_profile()
-        self.repoSelector.currentIndexChanged.connect(self.repo_select_action)
 
-    def populate_from_profile(self):
+        # populate repositories
+        self.set_repos()
+
+        # load profile configuration
         profile = self.profile()
         if profile.repo:
             self.repoSelector.setCurrentIndex(self.repoSelector.findData(profile.repo.id))
@@ -100,6 +99,8 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
         self.sshComboBox.setCurrentIndex(self.sshComboBox.findData(profile.ssh_key))
         self.init_repo_stats()
 
+        self.repoSelector.currentIndexChanged.connect(self.repo_select_action)
+
     def init_repo_stats(self):
         """Set the strings of the repo stats labels."""
         # prepare translations
@@ -110,6 +111,18 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
         # set labels
         repo: RepoModel = self.profile().repo
         if repo is not None:
+            self.frameRepoSettings.setEnabled(True)
+            # remove *unset* item
+            self.repoSelector.removeItem(self.repoSelector.findData(None))
+
+            # local repo doesn't use ssh
+            ssh_enabled = repo.is_remote_repo()
+            # self.bAddSSHKey.setEnabled(ssh_enabled)
+            # otherwise one cannot add a ssh key for adding a repo
+            self.sshComboBox.setEnabled(ssh_enabled)
+            self.sshKeyToClipboardButton.setEnabled(ssh_enabled)
+
+            # update stats
             if repo.unique_csize is not None:
                 self.sizeCompressed.setText(pretty_bytes(repo.unique_csize))
                 self.sizeCompressed.setToolTip('')
@@ -133,6 +146,10 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
 
             self.repoEncryption.setText(str(repo.encryption))
         else:
+            # Compression and SSH key are only valid entries for a repo
+            self.frameRepoSettings.setEnabled(False)
+
+            # unset stats
             self.sizeCompressed.setText(na)
             self.sizeCompressed.setToolTip(no_repo_selected)
 
@@ -189,9 +206,12 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
                 clipboard.setText(pub_key)
 
                 msg.setWindowTitle(self.tr("Public Key Copied to Clipboard"))
-                msg.setText(self.tr(
-                    "The selected public SSH key was copied to the clipboard. "
-                    "Use it to set up remote repo permissions."))
+                msg.setText(
+                    self.tr(
+                        "The selected public SSH key was copied to the clipboard. "
+                        "Use it to set up remote repo permissions."
+                    )
+                )
 
             else:
                 msg.setText(self.tr("Could not find public key."))
@@ -251,6 +271,10 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
         selected_repo_id = self.repoSelector.currentData()
         selected_repo_index = self.repoSelector.currentIndex()
 
+        if not selected_repo_id:
+            # QComboBox is empty / repo unset
+            return
+
         repo = RepoModel.get(id=selected_repo_id)
         ArchiveModel.delete().where(ArchiveModel.repo_id == repo.id).execute()
         profile.repo = None
@@ -265,12 +289,12 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
         msg.show()
 
         self.repo_changed.emit()
-        self.init_repo_stats()
+        self.populate_from_profile()
 
     def copy_URL_action(self):
         selected_repo_id = self.repoSelector.currentData()
         if not selected_repo_id:
-            # QComboBox is empty
+            # QComboBox is empty / repo unset
             return
 
         repo = RepoModel.get(id=selected_repo_id)
